@@ -142,7 +142,7 @@ class backgrounds(TemplateFormat):
     def processingFile(self, textConfigFile, rootPath=None, nameFile=None):
         """Обработка конфигурационного файла"""
         if not (self.convert_cmd and self.identify_cmd):
-            self.setError("%s. %s" % (_("Format 'backgrounds' is unavailable"),
+            self.setError("%s. %s" % (_("The 'backgrounds' format is unavailable"),
                                       _("Need to install {packages}").format(
                                           packages="media-gfx/imagemagick")))
             return False
@@ -213,6 +213,7 @@ class backgrounds(TemplateFormat):
                 fn = os.path.split(remove_fn)[1]
                 if re_remove.match(fn):
                     removed_files.append(remove_fn)
+        created = set()
         if source:
             for resolution in resolutions:
                 rule_match = reRule.search(resolution)
@@ -223,6 +224,10 @@ class backgrounds(TemplateFormat):
                 width, height = rule_match.groups()
                 width = int(width)
                 height = int(height)
+                if (width,height) in created:
+                    continue
+                else:
+                    created.add((width,height))
 
                 if only_one:
                     image_fn = pathJoin(workdir, prefix)
@@ -238,7 +243,7 @@ class backgrounds(TemplateFormat):
                     image_files.append(image_fn)
                 else:
                     self.parent.printWARNING(
-                        _("Skipped creation of the image with %s resolution") % (
+                        _("Creation of image with %s resolution skipped") % (
                             "%dx%d" % (width, height)))
             with writeFile(md5_fn) as f:
                 f.write("%s\n" % image_md5)
